@@ -24,7 +24,9 @@ from cellprofiler_core.measurement import Measurements
 from cellprofiler_core.object import ObjectSet
 from cellprofiler_core.pipeline import LoadException
 from cellprofiler_core.pipeline import Pipeline
-from cellprofiler_core.preferences import get_image_set_file, get_temporary_directory
+from cellprofiler_core.preferences import get_image_set_file
+from cellprofiler_core.preferences import get_temporary_directory
+from cellprofiler_core.preferences import set_conserve_memory
 from cellprofiler_core.preferences import get_omero_port
 from cellprofiler_core.preferences import get_omero_server
 from cellprofiler_core.preferences import get_omero_session_id
@@ -194,6 +196,10 @@ def main(args=None):
     if options.plugins_directory is not None:
         set_plugin_directory(options.plugins_directory, globally=False)
 
+    if options.conserve_memory is not None:
+        set_conserve_memory(options.conserve_memory, globally=False)
+
+
     if not options.allow_schema_write:
         set_allow_schema_write(False)
 
@@ -383,6 +389,13 @@ def parse_args(args):
         help="CellProfiler will look for plugin modules in this directory (headless-only).",
     )
 
+    parser.add_option(
+        "--conserve-memory",
+        dest="conserve_memory",
+        default=None,
+        help="CellProfiler will attempt to release unused memory after each image set.",
+    )
+
     parser.add_option(
         "--version",
         dest="print_version",
